@@ -45,6 +45,7 @@ create_custom_domain.short_description = "Create Custom Domain record for the AP
 class ApiGatewayAdditionalRouteInline(TabularInline):
     autocomplete_fields = ["api_gateway"]
     model = models.ApiGatewayAdditionalRoute
+    extra = 1
 
     def get_queryset(self, request):
         return super().get_queryset(request).select_related("api_gateway")
@@ -101,12 +102,7 @@ class ApiGatewayAdmin(ModelAdmin):
 class ApiGatewayAdditionalRouteAdmin(ModelAdmin):
     autocomplete_fields = ["api_gateway"]
     search_fields = ["name", "key"]
-    list_display = [
-        "name",
-        "api_gateway",
-        "route_key",
-        "integration_url",
-    ]
+    list_display = ["name", "api_gateway", "route_key", "integration_url", "deployed"]
     list_filter = ["api_gateway"]
     date_hierarchy = "created_on"
 
